# BaCa2-package-manager
_Package manager for BaCa2 (to be exported as PyPI package)._

Package manager designed to automatically interpret and work with task packages for BaCa2 checker.
It is needed for every kind of broker, and BaCa2 itself.
